@@ -12,7 +12,6 @@
 
 # --------------* IMPORT *-------------- #
 
-import datetime
 import os
 import pickle
 import smtplib
@@ -20,6 +19,10 @@ import ssl
 import sys
 import threading
 import time
+from email.mime.text import MIMEText
+from email.mime.multipart import MIMEMultipart
+import uuid
+import psutil
 
 # --------------* VARIABLES *-------------- #
 
@@ -202,39 +205,62 @@ def service_down(service, verbose):
 
 
 def send_mail(subject, verbose):
-    global sender_email, email_password, smtp_server, email_smtp_port, receiver_email
     if verbose:
         enablePrint()
+    global sender_email, email_password, smtp_server, email_smtp_port, receiver_email
 
     # Envoie un mail
-    now = datetime.datetime.now()
-    cpu_usage = """grep 'cpu ' /proc/stat | awk '{usage=($2+$4)*100/($2+$4+$5)} END {print usage "%"}' """
+    now = time.ctime()
 
-    cpu_temp = "cat /sys/class/thermal/thermal_zone*/temp"
-    cpu_temp = int(os.popen(cpu_temp).read())
-    cpu_temp = "{:,}".format(cpu_temp)
+    cpu_usage = str(round(float(os.popen(
+        '''grep 'cpu ' /proc/stat | awk '{usage=($2+$4)*100/($2+$4+$5)} END {print usage }' ''').readline()), 2))
 
-    message = f"""\
-    Subject: Oh non le service {subject} à planté !
+    ram_used = psutil.virtual_memory()[2]
 
-    Bonjour, Je tiens à vous informer que ce jour le {now.day}/{now.month}/{now.year} à {now.hour}:{now.minute} le 
-    service intitulé {subject} à planté.
-    {number_restart} operation affin de le relancer ont toutes échouées
-    
-    Information système : 
-    CPU Temp = {cpu_temp}°C
-    CPU Usage = {os.system(cpu_usage)}
-    From Auto_Check_service Python Bot"""
+    cpu_temp = psutil.sensors_temperatures()["cpu_thermal"][0]
+
+    disk_usage = psutil.disk_usage(os.sep).percent
+
+    uuid = uuid.uuid1()
+
+    print(psutil.cpu_percent(percpu=False))
+    print(cpu_usage)
+
+    text = f"""\
+Subject: The {subject} service is down
+
+
+
+
+
+
+
+
+
+Cpu Temp : {cpu_temp.current}°C                                                                                   
+Date : {now}
+Service name : {subject}  
+Ram Used : {ram_used}%     
+Disk Used : {disk_usage}%     
+Cpu Usage : {cpu_usage}%  
+ 
+.................................
+id : {uuid}
+.................................
+
+Send From https://github.com/FLAFLALEBG/Ultimate_Auto_Check_Services
+"""
 
     try:
         context = ssl.create_default_context()
         with smtplib.SMTP_SSL(smtp_server, email_smtp_port, context=context) as server:
             server.login(sender_email, email_password)
-            server.sendmail(sender_email, receiver_email, message.encode("utf8"))
+            server.sendmail(sender_email, receiver_email, text.encode("utf-8"))
 
             print("Successful sending mail")
 
     except:
+        print(f"Mail with id {uuid} error")
         print(f"Sending error please check the sender's email ({sender_email}) and password or the receiver's "
               f"({receiver_email})")
 
